You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@pdfbox.apache.org by ti...@apache.org on 2020/08/11 17:18:49 UTC

svn commit: r1880781 - in /pdfbox/trunk/pdfbox/src/test: java/org/apache/pdfbox/filter/TestFilters.java resources/org/apache/pdfbox/filter/PDFBOX-1777.bin resources/org/apache/pdfbox/filter/PDFBOX-1977.bin

Author: tilman
Date: Tue Aug 11 17:18:48 2020
New Revision: 1880781

URL: http://svn.apache.org/viewvc?rev=1880781&view=rev
Log:
PDFBOX-4933: very late correction to actual issue number

Added:
    pdfbox/trunk/pdfbox/src/test/resources/org/apache/pdfbox/filter/PDFBOX-1977.bin
      - copied unchanged from r1880516, pdfbox/trunk/pdfbox/src/test/resources/org/apache/pdfbox/filter/PDFBOX-1777.bin
Removed:
    pdfbox/trunk/pdfbox/src/test/resources/org/apache/pdfbox/filter/PDFBOX-1777.bin
Modified:
    pdfbox/trunk/pdfbox/src/test/java/org/apache/pdfbox/filter/TestFilters.java

Modified: pdfbox/trunk/pdfbox/src/test/java/org/apache/pdfbox/filter/TestFilters.java
URL: http://svn.apache.org/viewvc/pdfbox/trunk/pdfbox/src/test/java/org/apache/pdfbox/filter/TestFilters.java?rev=1880781&r1=1880780&r2=1880781&view=diff
==============================================================================
--- pdfbox/trunk/pdfbox/src/test/java/org/apache/pdfbox/filter/TestFilters.java (original)
+++ pdfbox/trunk/pdfbox/src/test/java/org/apache/pdfbox/filter/TestFilters.java Tue Aug 11 17:18:48 2020
@@ -131,16 +131,16 @@ public class TestFilters extends TestCas
     }
 
     /**
      * This will test the LZW filter with the sequence that failed in PDFBOX-1777.
      * To check that the test itself is legit, revert LZWFilter.java to rev 1571801,
      * which should fail this test.
      * 
      * @throws IOException 
      */
-    public void testPDFBOX1777() throws IOException
+    public void testPDFBOX1977() throws IOException
     {
         Filter lzwFilter = FilterFactory.INSTANCE.getFilter(COSName.LZW_DECODE);
-        byte[] byteArray = IOUtils.toByteArray(this.getClass().getResourceAsStream("PDFBOX-1777.bin"));
+        byte[] byteArray = IOUtils.toByteArray(this.getClass().getResourceAsStream("PDFBOX-1977.bin"));
         checkEncodeDecode(lzwFilter, byteArray);
     }
@@ -131,16 +131,16 @@ public class TestFilters extends TestCas
 
     /**
-     * This will test the LZW filter with the sequence that failed in PDFBOX-1777.
+     * This will test the LZW filter with the sequence that failed in PDFBOX-1977.
      * To check that the test itself is legit, revert LZWFilter.java to rev 1571801,
      * which should fail this test.